@@ -87,20 +87,16 @@ static inline void CONSOLE_BRIDGE_DEPRECATED console_bridge_deprecated() {}
   console_bridge::log(__FILE__, __LINE__, console_bridge::CONSOLE_BRIDGE_LOG_DEBUG, fmt, ##__VA_ARGS__)
 
 #define logError(fmt, ...)  \
-  console_bridge_deprecated(); \
-  console_bridge::log(__FILE__, __LINE__, console_bridge::CONSOLE_BRIDGE_LOG_ERROR, fmt, ##__VA_ARGS__)
+  console_bridge::log_deprecated(__FILE__, __LINE__, console_bridge::CONSOLE_BRIDGE_LOG_ERROR, fmt, ##__VA_ARGS__)
 
 #define logWarn(fmt, ...)   \
-  console_bridge_deprecated(); \
-  console_bridge::log(__FILE__, __LINE__, console_bridge::CONSOLE_BRIDGE_LOG_WARN,  fmt, ##__VA_ARGS__)
+  console_bridge::log_deprecated(__FILE__, __LINE__, console_bridge::CONSOLE_BRIDGE_LOG_WARN,  fmt, ##__VA_ARGS__)
 
 #define logInform(fmt, ...) \
-  console_bridge_deprecated(); \
-  console_bridge::log(__FILE__, __LINE__, console_bridge::CONSOLE_BRIDGE_LOG_INFO,  fmt, ##__VA_ARGS__)
+  console_bridge::log_deprecated(__FILE__, __LINE__, console_bridge::CONSOLE_BRIDGE_LOG_INFO,  fmt, ##__VA_ARGS__)
 
 #define logDebug(fmt, ...)  \
-  console_bridge_deprecated(); \
-  console_bridge::log(__FILE__, __LINE__, console_bridge::CONSOLE_BRIDGE_LOG_DEBUG, fmt, ##__VA_ARGS__)
+  console_bridge::log_deprecated(__FILE__, __LINE__, console_bridge::CONSOLE_BRIDGE_LOG_DEBUG, fmt, ##__VA_ARGS__)
 
 
 /** \brief Message namespace. This contains classes needed to
@@ -199,6 +195,11 @@ CONSOLE_BRIDGE_DLLAPI LogLevel getLogLevel(void);
     but rather used via a \ref logging "logging macro".  Formats the message
     string given the arguments and forwards the string to the output handler */
 CONSOLE_BRIDGE_DLLAPI void log(const char *file, int line, LogLevel level, const char* m, ...);
+
+/** \brief Root level logging function.  This should not be invoked directly,
+    but rather used via a \ref logging "logging macro".  Formats the message
+    string given the arguments and forwards the string to the output handler */
+CONSOLE_BRIDGE_DEPRECATED CONSOLE_BRIDGE_DLLAPI void log_deprecated(const char *file, int line, LogLevel level, const char* m, ...);
 }
 
 
